/* 
   File to run market value regressions on R&D and intangible stocks.
   Outputs the R&D coefficients needed to recalculate productivity in the J-Curve Notebook.
*/

clear
/* CHANGE THIS TO YOUR WORKING DIRECTORY FOR THE COMPUSTAT FILE AND DATA DIRECTORY
import delimited "~/JCurve/Data/growthAcct_compustat.csv"
cd "~/Jcurve/Data"
*/

*Generate the categorical variables needed for FEs
egen naicsFour = group(naics4)
egen naicsThree = group(naics3)
*encode(naics4), gen(naicsFour)
*encode(naics3), gen(naicsThree)
encode(symbol), gen(ticker)

*R&D_regs.doc will contain the columns of Table 1

*No fixed effects or controls
reg mv at k_int_know if year>1961, vce(robust)
outreg2 using R&D_regs.doc, replace ctitle(Basic R&D) addtext(Year FE, No, Industry FE, No, Industry-Year FE, No, Firm FE, No)

reg mv at k_int_know k_int_org if year>1961, vce(robust)
outreg2 using R&D_regs.doc, append ctitle(Basic R&D and Org) addtext(Year FE, No, Industry FE, No, Industry-Year FE, No, Firm FE, No)

*Fixed Effects for Industry and Year
reghdfe mv at k_int_know if year>1961, absorb(naicsFour##year) vce(cluster naicsFour)
outreg2 using R&D_regs.doc, append ctitle(Industry FE - R&D) addtext(Year FE, Yes, Industry FE, Yes, Industry-Year FE, Yes, Firm FE, No)

reghdfe mv at k_int_know k_int_org if year>1961, absorb(naicsFour##year) vce(cluster naicsFour)
outreg2 using R&D_regs.doc, append ctitle(Industry FE - R&D and Org) addtext(Year FE, Yes, Industry FE, Yes, Industry-Year FE, Yes, Firm FE, No)

*Fixed Effects for Firm and Year
reghdfe mv at k_int_know if year>1961, absorb(ticker year) vce(cluster ticker)
outreg2 using R&D_regs.doc, append ctitle(Firm FE - R&D) addtext(Year FE, Yes, Industry FE, No, Industry-Year FE, No, Firm FE, Yes)

reghdfe mv at k_int_know k_int_org if year>1961, absorb(ticker year) vce(cluster ticker)
outreg2 using R&D_regs.doc, append ctitle(Firm FE - R&D and Org) addtext(Year FE, Yes, Industry FE, No, Industry-Year FE, No, Firm FE, Yes)

*Year by year regression
statsby _b _se, by(year) clear: reghdfe mv at k_int_know, absorb(naicsFour) vce(cluster naicsFour)

**Change this to what you need it to be
*This code generates the coefficients needed for the J-Curve R&D Adjustment.
*It also generates the figures 3 and 4.
export delimited "~/JCurve/Data/R&D_byYear.csv"

gen theOne = 1
gen hi = _b_k_int_know + 1.96*_se_k_int_know
gen lo = _b_k_int_know - 1.96*_se_k_int_know

gen athi = _b_at + 1.96*_se_at
gen atlo = _b_at - 1.96*_se_at

line _b_k_int_know year if year>1961||line hi year if year>1961 || line lo year if year>1961||line theOne year if year>1961||, xtitle("Year") ytitle("R&D Coefficient ($)") title("Market Value R&D Coefficients by Year") legend(label(1 "R&D Coefficient Estimate") label(2 "Upper 95% CI") label(3 "Lower 95% CI") label(4 "$1 Replacement Value"))

**Change this to what you need it to be
graph save Graph "~/JCurve/Figures/r&d_byYear.gph"

line _b_at year if year>1961||line athi year if year>1961 || line atlo year if year>1961||line theOne year if year>1961||, xtitle("Year") ytitle("Total Assets Coefficient ($)") title("Market Value Total Assets Coefficients by Year") legend(label(1 "Total Assets Coefficient Estimate") label(2 "Upper 95% CI") label(3 "Lower 95% CI") label(4 "$1 Replacement Value"))

**Change this to what you need it to be
graph save Graph "~/JCurve/Figures/TA_byYear.gph"
