# ReadMe - The Productivity J-Curve (openicpsr-117947)

There are a number of files included for the code and data appendix. The code files are:

1. MVReg_Preprocessor.ipynb
2. MVReg_Intangibles.do
3. jCurveDataConstructor.ipynb
4. Peters_and_Taylor_Extension.ipynb*

and the input data (csv) files are:

1. quarterly_tfp, capInputWeights, capShares, and capStocks for use with jCurveDataCosntructor.ipynb, 
2. GDPShortfallOutput.xlsx (a .csv version exists in missingGDPCalculationTable), and
3. jcurveFig1Data.csv

Derived data to run the jCurveDataConstructor notebook without Compustat access are contained in R&D_byYear.csv. 

Locations where filepaths should be changed to reflect the user configuration are marked in the code with comments.

The MVReg_preprocessor notebook takes in Compustat-CapitalIQ data on firm-level financials from 1950-2018 as well as the Peters and Taylor (2017) total Q series. Both of these are available via WRDS (details below). It produces a dataset prepared for Stata called "growthAcct_compustat.csv". This is the main input to MVReg_Intangibles.do.

MVReg_Intangibles.do produces Table 1 (in R&D_regs.doc), Figures 3 and 4, and a file with coefficient estimates by year for the regression of market value on R&D stocks from Peters and Taylor (2017). This file, R&D_byYear.csv, is an input to the jCurveDataConstructor.ipynb notebook. Make sure to have reghdfe (at least 3.2.9) installed for Stata in order to run this code. We recommend at least Stata 15.0. Information on reghdfe is available here: http://scorreia.com/software/reghdfe/install.html. 

jCurveDataConstructor.ipynb creates all other figures and tables, in addition to the inputs for GDPShortfallOutput.xlsx (where our counterfactual calculations if growth rates had stayed constant for sections VI and VII are found). Figure 1 is produced using the toy economy data in jcurveFig1Data.csv. The other csv files listed in data item 1 above are sourced from John Fernald (http://www.johnfernald.net/TFP) and the U.S. Bureau of Economic Analysis fixed asset investment and capital stock national accounts (https://www.bea.gov/data/investment-fixed-assets/by-type). The Fernald TFP series and BEA fixed asset series excel file also includes variable descriptions. For this notebook, we recommend python 3.7 with pandas (0.25.1), numpy (1.17.2), and matplotlib (3.1.1) installed. 

BEA Fixed Asset Tables are available here: https://www.bea.gov/data/investment-fixed-assets/by-type. Each excel file contains details on the construction, and all tables are available as well under the "Nonresidential Detailed Estimates" section here: https://apps.bea.gov/national/FA2004/Details/Index.htm. We use the current cost estimates. For investment and capital stock shares, capital service flow and investment items are divided by total output following Fernald (2014). Sample input weight files that we use in the analysis are included.

More details and instructions are also available in the code and its comments.

**Important Note: All files require the user to specify the relevant directories and filepaths prior to running any code.**

*Peters_and_Taylor_Extension.ipynb adds detail on extending the total Q series beyond available years in WRDS, but is not necessary to include for years already covered by WRDS.  

Wharton Research Data Services (WRDS) is available here: https://wrds-www.wharton.upenn.edu/. To get access to WRDS data, you will need to register for an account through your institution or otherwise. Account registration is available at: https://wrds-web.wharton.upenn.edu/wrds/?register.

For researchers with access to WRDS through their institution, a subscription to Compustat - Capital IQ's North America - Daily Fundamentals Annual dataset is required. The Compustat - Capital IQ query interface with all years and companies selected and all listed variables below selected will yield a file that can serve as an input to MVReg_Preprocessor.ipynb. Just replace the compustatFile string variable with the path to the Compustat file in the MVReg_Preprocessor.ipynb script. Similarly, a Peters and Taylor Total Q subscription will be required via WRDS. Select all variables and years in the query tool, then save the file and replace the peters_and_taylor_file string variable with the path to the output of the Peters and Taylor Total Q series query. These two series should be accessible on the listed subscriptions page once an account is registered.

This volume is also available at http://drock.mit.edu/Research.

**Required Variables for Market Value Regression on R&D Intangibles** (MVReg_Intangibles.do)

The variables below are required to run the market value regressions in MVReg_Intangibles.do. Some of these variables are preprocessed using data from Compustat (accessed via WRDS). Peters and Taylor (2017) intangible capital stocks are also accessible via WRDS, or, for more recent years, calculated following the method described in the article:

Peters, Ryan H., and Lucian A. Taylor. "Intangible capital and the investment-q relation." *Journal of Financial Economics* 123, no. 2 (2017): 251-272.

Calculation of Table 1, construction of Figures 3 and 4, and the production of the R&D investment multipliers necessarily use this script. For users interested in only the J-Curve adjustment, the multipliers are available in the Derived Data folder in this volume.

Required Compustat Fields:

gvkey (firm identifier), fyear, tic, at, prcc_c, cash, ceq, ppegt, intan, gdwl, naics

Required Peters and Taylor (2017) fields
gvkey, fyear, K_int_Know, K_int_Org, K_int_offBS, K_int, q_tot

*All of these variables will should be present in the output file for the included notebook MVReg_Preprocessor.ipynb. We recommend downloading data from WRDS and using the attached notebooks to prepare the data for the MVReg_Intangibles .do file.*

growthAcct_compustat.csv Input File Variable Name: Variable Description

- naics4 : 4-digit NAICS code as a string (code generates dummies) 
- naics3 : 3-digit NAICS code as a string (code generates dummies) 
- symbol : generates the encoding for the variable `ticker'
- year : integer for the reporting year
- mv : float with market valuation in millions USD
- at : Compustat item reflecting total book value of assets in millions USD
- k_int_know : R&D intangible capital from Peters and Taylor (2017)
- k_int_org : Organizational capital (capitalized SG&A) from Peters and Taylor (2017)

